==> netbluemind4-4.1.64823.tar.gz: netbluemind4-4.1.64823/netbluemind/backend/mail/api/SearchQueryHeaderQuery.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SearchQueryHeaderQuery :
    def __init__( self):
        self.logicalOperator = None
        self.query = None
        pass

class __SearchQueryHeaderQuerySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = SearchQueryHeaderQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import SearchQueryLogicalOperator
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import __SearchQueryLogicalOperatorSerDer__
        logicalOperatorValue = value['logicalOperator']
        instance.logicalOperator = __SearchQueryLogicalOperatorSerDer__().parse(logicalOperatorValue)
        from netbluemind.backend.mail.api.SearchQueryHeader import SearchQueryHeader
        from netbluemind.backend.mail.api.SearchQueryHeader import __SearchQueryHeaderSerDer__
        queryValue = value['query']
        instance.query = serder.ListSerDer(__SearchQueryHeaderSerDer__()).parse(queryValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import SearchQueryLogicalOperator
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import __SearchQueryLogicalOperatorSerDer__
        logicalOperatorValue = value.logicalOperator
        instance["logicalOperator"] = __SearchQueryLogicalOperatorSerDer__().encode(logicalOperatorValue)
        from netbluemind.backend.mail.api.SearchQueryHeader import SearchQueryHeader
        from netbluemind.backend.mail.api.SearchQueryHeader import __SearchQueryHeaderSerDer__
        queryValue = value.query
        instance["query"] = serder.ListSerDer(__SearchQueryHeaderSerDer__()).encode(queryValue)
        return instance

==> netbluemind5-5.3.2932.tar.gz: netbluemind5-5.3.2932/netbluemind/backend/mail/api/SearchQueryHeaderQuery.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SearchQueryHeaderQuery:
    def __init__(self):
        self.logicalOperator = None
        self.query = None
        pass


class __SearchQueryHeaderQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SearchQueryHeaderQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import SearchQueryLogicalOperator
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import __SearchQueryLogicalOperatorSerDer__
        logicalOperatorValue = value['logicalOperator']
        instance.logicalOperator = __SearchQueryLogicalOperatorSerDer__().parse(
            logicalOperatorValue)
        from netbluemind.backend.mail.api.SearchQueryHeader import SearchQueryHeader
        from netbluemind.backend.mail.api.SearchQueryHeader import __SearchQueryHeaderSerDer__
        queryValue = value['query']
        instance.query = serder.ListSerDer(
            __SearchQueryHeaderSerDer__()).parse(queryValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import SearchQueryLogicalOperator
        from netbluemind.backend.mail.api.SearchQueryLogicalOperator import __SearchQueryLogicalOperatorSerDer__
        logicalOperatorValue = value.logicalOperator
        instance["logicalOperator"] = __SearchQueryLogicalOperatorSerDer__().encode(
            logicalOperatorValue)
        from netbluemind.backend.mail.api.SearchQueryHeader import SearchQueryHeader
        from netbluemind.backend.mail.api.SearchQueryHeader import __SearchQueryHeaderSerDer__
        queryValue = value.query
        instance["query"] = serder.ListSerDer(
            __SearchQueryHeaderSerDer__()).encode(queryValue)
        return instance
